@@ -34,7 +34,6 @@
 #include <KHTMLView>
 #include <KToolBarPopupAction>
 #include <KSharedConfig>
-#include <kcoreaddons_version.h>
 #include <docbookxslt.h>
 
 #include <QClipboard>
@@ -163,7 +162,7 @@ void View::beginSearchResult()
 {
   mState = Search;
 
-  begin( QUrl( QLatin1Literal( "khelpcenter:search/result" ) ) );
+  begin( QUrl( QStringLiteral( "khelpcenter:search/result" ) ) );
   mSearchResult = QString();
 }
 
@@ -196,7 +195,7 @@ void View::lastSearch()
 
   mState = Search;
 
-  begin( QUrl( QLatin1Literal( "khelpcenter:search/last" ) ) );
+  begin( QUrl( QStringLiteral( "khelpcenter:search/last" ) ) );
   write( mSearchResult );
   end();
 }
